import argparse
import logging
from .vcf import  vcard_generator

logging.basicConfig(format='%(levelname)s:%(message)s', level=logging.INFO)


usage = "vcf_creator"
parser = argparse.ArgumentParser(usage)

print("""
  _    ______________   ______                __            
 | |  / / ____/ ____/  / ____/_______  ____ _/ /_____  _____
 | | / / /   / /_     / /   / ___/ _ \/ __ `/ __/ __ \/ ___/
 | |/ / /___/ __/    / /___/ /  /  __/ /_/ / /_/ /_/ / /    
 |___/\____/_/       \____/_/   \___/\__,_/\__/\____/_/                                                             
 """)

parser.add_argument("filename", type=str, help="input csv file")

parser.add_argument("-o", "--out",
                  metavar="FILE",
                  help="write output to FILE.vcf "
                        "[default:<input filename>.vcf]")

args= parser.parse_args()

if args.out == None:
  out_file = args.filename.split(".")[0] + ".vcf"
else:
  out_file = args.out + ".vcf"

res = vcard_generator(args.filename)
if res != -1:
  with open(out_file , "w+") as file:
    file.write(res)
    # print("vCard file written.")
    logging.info("vCard file written.")
else:
  logging.error("Exiting.")



import csv
import os.path
import logging

logging.basicConfig(format='%(levelname)s:%(message)s', level=logging.INFO)

ATTRIBUTES = {
    "name": "FN",
    "organisation": "ORG",
    "phone": "TEL;WORK;VOICE",
    "email": "EMAIL",
    "address": "ADR;HOME",
    "birthday": "BDAY"
}

attributes_present = {}

def vcard_formatter(values):
    """
    Parameters
    ---------
    values: array of data present in a row

    Returns
    -------
    str
        a string of vcard formatted row
    """

    ret = ["BEGIN:VCARD", "VERSION:4.0"]

    for attr in ATTRIBUTES.keys():
        if attr in attributes_present.keys():
            ret.append(ATTRIBUTES[attr] + ":" + values[attributes_present[attr]])
    
    ret.append("END:VCARD")
    return "\n".join(ret)
    
def vcard_generator(filename):
    """
    Parameters
    ---------
    filename: csv file to process
       
    Returns
    -------
    str
        a string of vcard formatted data
    
    """

    # Check if the file exists
    if not os.path.isfile(filename):                        
        # print("File doesn't exist.")
        logging.error("File doesn't exist.")
        return -1
    else:
        # print("File found. Processing...")
        logging.info("File found. Processing...")
        with open(filename, newline='') as csvfile:
            # Perform various checks on the csv dialect
            try:
                head = csvfile.readline()
                logging.info("Header is " + head.strip())
                dialect = csv.Sniffer().sniff(head)
                # Reset the read position back to the start
                csvfile.seek(0)
            except csv.Error:
                # print("File appears not to be in csv format.")
                logging.error("File appears not to be in csv format.")
                return -1

            # Read the csv file
            reader = csv.reader(csvfile, dialect)
            # Get header
            header = [h.strip().lower() for h in reader.__next__()]
            # Name is required
            if "name" not in header:
                # print("Header not supported.")
                logging.error("Header not supported.")
                return -1

            # Set attributes_present
            for i, attr in enumerate(header):
                attributes_present[attr] = i
            
            ret = []
            # Iterate over the rows
            for row in reader:
                ret.append(vcard_formatter(row))

            # print("Done processing.")
            logging.info("Done processing.")
            return "\n".join(ret)



import argparse
import logging
from .vcf import vcard_generator

logging.basicConfig(format='%(levelname)s:%(message)s', level=logging.INFO)

def main():
    usage = "vcf_creator"
    parser = argparse.ArgumentParser(usage)

    print("""
     _    ______________   ______                __            
    | |  / / ____/ ____/  / ____/_______  ____ _/ /_____  _____
    | | / / /   / /_     / /   / ___/ _ \/ __ `/ __/ __ \/ ___/
    | |/ / /___/ __/    / /___/ /  /  __/ /_/ / /_/ /_/ / /    
    |___/\____/_/       \____/_/   \___/\__,_/\__/\____/_/                                                             
    """)

    parser.add_argument("filename", type=str, help="input csv file")

    parser.add_argument("-o", "--out",
                    metavar="FILE",
                    help="write output to FILE.vcf "
                            "[default:<input filename>.vcf]")

    args= parser.parse_args()

    if args.out == None:
        out_file = args.filename.split(".")[0] + ".vcf"
    else:
        out_file = args.out + ".vcf"

    res = vcard_generator(args.filename)
    if res != -1:
        with open(out_file , "w+") as file:
            file.write(res)
            # print("vCard file written.")
            logging.info("vCard file written.")
    else:
        logging.error("Exiting.")



import os 
import unittest
from vcf_creator.vcf import *

csv = os.path.join(os.path.dirname(__file__), 'test.csv')
vcf = os.path.join(os.path.dirname(__file__), 'test.vcf')

class TestVcf(unittest.TestCase):

    def test_vcf_generator(self):
        result = vcard_generator(csv)
        with open(vcf, "r") as file:
            text = file.read()
        self.assertEqual(result, text)       

if __name__ == '__main__':
    unittest.main()